import { FilesCollection } from 'meteor/ostrio:files';
import { Meteor } from 'meteor/meteor';
import { check } from 'meteor/check';

/**
 * A file collection from the Meteor-Files package to handle adding new map images on the admin side
 */
export const MapImages = new FilesCollection({
  collectionName: 'MapImages',
  allowClientCode: false,
  onBeforeUpload(file) {
    // Only accept upload files under 10MB, and only in svg/ png/jpg/jpeg formats
    if (file.size <= 10485760 && /svg|png|jpg|jpeg/i.test(file.extension)) {
      return true;
    }
    return 'Image size exceed limit of 10MB. Please upload a smaller image.';
  },
});

/**
 * Publish the collection of map images so they are readily available
 */
if (Meteor.isServer) {
  // Publish the set of available images
  Meteor.publish('mapimages', function mapImagePublication() {
    return MapImages.collection.find({});
  });
}

/**
 * Define a set of API calls for uploading and rendering images
 */
Meteor.methods({

  /**
     * Gets a list of links to an image from the list of imageIDs
     * @param mapImageIDs A list of image ID
     */
  'mapimages.getImageLinks'(mapImageIDs) {
    check(mapImageIDs, [Number]);

    const links = [];
    mapImageIDs.forEach((id) => {
      links.push(MapImages.findOne({ _id: id }).link());
    });

    return links;
  },

  /**
     * Gets a link for the image ID
     * @param mapImageID A single image ID
     */
  'mapimages.getImageLink'(mapImageID) {
    check(mapImageID, Number);

    return MapImages.findOne({ _id: mapImageID }).link();
  },
});
