import { Mongo } from 'meteor/mongo';
import { Meteor } from 'meteor/meteor';
import { check } from 'meteor/check';

export const Plugins = new Mongo.Collection('plugins');

if (Meteor.isServer) {
  // Publish the set of available maps
  Meteor.publish('plugins', function pluginsPublication() {
    return Plugins.find({});
  });
}

// A set of API methods for the plugins that can be accessed via Meteor.call
Meteor.methods({

  /**
     * Registers a new plugin into the database
     * @param name Name of the plugin defined in the PluginList list
     */
  'plugins.registerPlugin'(name) {
    check(name, String);

    if (Plugins.find({ name }).count() === 0) { // if it doesn't already exist
      Plugins.insert({
        _id: Random.id(),
        name,
        installed: false,
      });
    }
  },

  /**
     * Inverts the installation status of a plugin. Uninstalling a plugin will
     * not delete previous data.
     * @param name Name of the plugin to update
     */
  'plugins.togglePlugin'(name) {
    check(name, String);

    const currentStatus = Plugins.findOne({ name }).installed;

    Plugins.update({ name }, {
      $set: {
        installed: !currentStatus,
      },
    });
  },

  /**
   * Sets the configuration of the plugin
   * @param {*} name 
   * @param {*} settings 
   */
  'plugins.setConfig'(name, settings){
    check(name, String);

    Plugins.update({ name }, {
      $set: {
        config: settings,
      },
    });
  },

  /**
     * Determines if a plugin with the given name already exists in the database
     * @param name Name of the plugin
     * @returns {boolean} True if the name exists in the db, False otherwise
     */
  'plugins.isRegistered'(name) {
    check(name, String);

    if (Plugins.find({ name }).count() === 0) {
      return false;
    }
    return true;
  },

});
