import { ReactMeteorData, createContainer } from 'meteor/react-meteor-data';
import React, { Component, PropTypes } from 'react';
import { Meteor } from 'meteor/meteor';
import { _ } from 'meteor/underscore';
import { MapImages } from '../../api/collections/mapimages';

class FileUploadComponent extends Component {
  constructor(props) {
    super(props);

    this.state = {
      mixins: [ReactMeteorData],
      uploading: [],
      progress: 0,
      inProgress: false,
    };
  }

    uploadFile = (uploadEvent) => {


      uploadEvent.preventDefault();

      // If files are selected for uploading, we want to ensure the first file exists
      if (!!uploadEvent.currentTarget.files && !!uploadEvent.currentTarget.files[0]) {
        const file = uploadEvent.currentTarget.files[0]; // get the file to upload

        if (file) {
          const self = this;
          // This is a special case where I want to insert from the client side
          const uploadInstance = MapImages.insert({
            file,
            meta: {
              locator: this.props.fileLocator,
              userId: Meteor.userId(), // Optional, used to check on server for file tampering
            },
            streams: 'dynamic',
            chunkSize: 'dynamic',
            allowWebWorkers: true, // If you see issues with uploads, change this to false
          }, false);

          this.setState({
            uploading: uploadInstance, // Keep track of this instance to use below
            inProgress: true, // Show the progress bar now
          });

          // These are the event functions, don't need most of them, it shows where we are in the process
          uploadInstance.on('start', function () {
            console.log('Starting');
          });
          uploadInstance.on('end', function (error, fileObj) {
            console.log('On end File Object: ', fileObj);
          });
          uploadInstance.on('uploaded', function (error, fileObj) {
            console.log('uploaded: ', fileObj);

            // Remove the filename from the upload box
            // self.refs.fileinput.value = '';

            // Reset our state for the next file
            self.setState({
              uploading: [],
              progress: 0,
              inProgress: false,
              recentUpload: fileObj,
            });

            // Pass the ID back to the popup so it can be saved to the database
            self.props.onUploadComplete(fileObj);
          });
          uploadInstance.on('error', function (error, fileObj) {
            console.log(`Error during upload: ${error}`);
          });
          uploadInstance.on('progress', function (progress, fileObj) {
            console.log(`Upload Percentage: ${progress}`);
            // Update our progress bar
            self.setState({
              progress,
            });
          });
          uploadInstance.start(); // Must manually start the upload
        }
      }
    }

    render() {
      if (this.props.filesReadyYet) {
        'use strict';

        let display = null;
        if (this.state.recentUpload) {
          const link = MapImages.findOne({ _id: this.state.recentUpload._id }).link(); // A link to the image in the collection

          // Image representing the most recently uploaded file
          display = (<div>
                            <img style={{width: '100%', height: '100%'}} src={link}/>
                         </div>);
        } else if (this.props.image && !this.state.recentUpload) {
          const link = this.props.image;

          display = (<div>
                    <img style={{width: '100%', height:'100%'}} src={link}/>
                </div>);
        }

        return (<div>
                <div>
                    <div>
                        <p>Upload New File:</p>
                        <input type="file" id="fileinput" disabled={this.state.inProgress} ref="fileinput"
                               onChange={this.uploadFile}/>
                    </div>
                </div>
                {/*display*/}
            </div>);
      }
      return <div />;
    }
}

FileUploadComponent.propTypes = {
  filesReadyYet: PropTypes.bool.isRequired,
  files: PropTypes.array.isRequired,

  onUploadComplete: PropTypes.func.isRequired, // to be passed by AddMapPopup
};

/**
 * Meteor default container for this component. Will subscribe to the database and populate the "files" and filesReady props
 * when the container is created.
 */
export default createContainer(() => {
  const handle = Meteor.subscribe('mapimages');
  const files = MapImages.find().fetch();

  return {
    filesReadyYet: handle.ready(),
    files, // initially empty, but will be updated after the first render
  };
}, FileUploadComponent);
