import React, {PropTypes, Component} from 'react';
import {Meteor} from 'meteor/meteor';
import RouteInput from "./RouteInput";
import RaisedButton from 'material-ui/RaisedButton';
import Paper from 'material-ui/Paper';

import Toolbar from 'material-ui/Toolbar';
import ToolbarGroup from 'material-ui/Toolbar/ToolbarGroup';
import ToolbarSeperator from 'material-ui/Toolbar/ToolbarSeparator';

export default class RoutingComponent extends Component {
    constructor(props){
        super(props);

        this.state = {
            startText: '',
            endText: '',
        }
    }

    /**
     * Updates the state of the start field based on what is typed in
     * @param text New text value
     */
    handleStartSelection = (text) => {
        this.setState({startText: text});
    }
    /**
     * Updates the state of the end field based on what is typed in
     * @param text New text value
     */
    handleEndSelection = (text) => {
        this.setState({endText: text});
    }

    /**
     * Calls the route function in MapContainer by passing the names of the locations for routing
     */
    handleClick = () => {
        this.props.onRoute(this.state.startText, this.state.endText);
    }

    render(){
        return (
            <Paper className="routing-component" style={componentStyles}>
                <RouteInput
                    options={this.props.locations}
                    onSelection={this.handleStartSelection}
                    placeholder='starting location...'/>
                <RouteInput
                    options={this.props.locations}
                    onSelection={this.handleEndSelection}
                    placeholder='ending location...'/>
                <ToolbarSeperator/>
                <RaisedButton
                        className="routing-button"
                        onClick={this.handleClick}>Route
                </RaisedButton>
            </Paper>
        );
    }
}

const componentStyles = {
    width: '33%',
    float: 'right',
    padding: '5px',
}

RoutingComponent.propTypes = {
    onRoute: PropTypes.func.isRequired,
    mapID: PropTypes.string.isRequired,
    locations: PropTypes.array.isRequired,
}