import { Component } from 'react';
import { Meteor } from 'meteor/meteor';
import { pluginList } from './PluginList';

/**
 * A base class for all plugins, defines which fields all plugins must have
 */
export default class PluginBase extends Component {
  /**
     * Constructor for a plugin
     * @param props Props from the parent component
     * @param name Name of the plugin which comes from PluginList.js
     * @param installed Indicates if this plugin is currently installed
     * @param registered Indicates if this plugin is in the database or not
     */
  constructor(props, name, installed = false, registered = false) {
    super(props);

    this.name = name;
    this.installed = installed;
    this.registered = registered;

    // Determine if the plugin has been registered or not
    Meteor.call('plugins.isRegistered', name, function(err, res) {
      if (!err) {
        if (!res) {
          const parsedName = name.split(' ').join('_');
          pluginList.name = parsedName.toUpperCase();
          Meteor.call('plugins.registerPlugin', name);
        }

        this.registered = true;
      } else {
        console.log(err);
      }
    }.bind(this));
  }
}
