import {pluginList} from "./PluginList";
import React from "react";
import SchoolDirectoryPlugin from "./plugins/schooldirectory/SchoolDirectoryPlugin";
import LoggerPlugin from "./plugins/logger/LoggerPlugin";
import AnalyticsPlugin from "./plugins/analytics/AnalyticsPlugin";
import HospitalDirectoryPlugin from "./plugins/hospitaldirectory/HospitalDirectoryPlugin";
import AirportTimeTablePlugin from "./plugins/airporttimetable/AirportTimeTablePlugin";

export default class PluginFactory {

    /**
     * The heart of the factory pattern, this will build the React component for the input plugin
     * @param pluginData Data object containing the name and other information for the plugin
     * @returns {XML} React object
     */
    static build(pluginData, loadInfo){
        switch(pluginData.name){
            case pluginList.schoolDirectory:
                return <SchoolDirectoryPlugin key={pluginData.name} loadInfo={loadInfo} data={pluginData}/>
            case pluginList.logger:
                return <LoggerPlugin key={pluginData.name} loadInfo={loadInfo} data={pluginData}/>
            case pluginList.analytics:
                return <AnalyticsPlugin key={pluginData.name} loadInfo={loadInfo} data={pluginData}/>
            case pluginList.hospitalDirectory:
                return <HospitalDirectoryPlugin key={pluginData.name} loadInfo={loadInfo} data={pluginData}/>
            case pluginList.airportTimetable:
                return <AirportTimeTablePlugin key={pluginData.name} loadInfo={loadInfo} data={pluginData}/>

            default:
                console.log('No such plugin name found');
        }
    }
}