import React, {Component, PropTypes} from 'react';
import { Meteor } from 'meteor/meteor';
import { createContainer } from 'meteor/react-meteor-data';

import {Plugins} from '../../../api/collections/plugins';
import PluginFactory from "../PluginFactory";

class PluginViewComponent extends Component {

    constructor(props){
        super(props);

        this.state = {
            info: null,
        }
    }

    loadInfo = (infoHTML) =>{
        this.setState({info: infoHTML});
    }

    render(){
        const renderedPlugins = this.props.plugins.map((plugin) => PluginFactory.build(plugin, this.loadInfo));

        return(
            <div className="plugin-layout">
                <div className="plugin-gallery-view">
                    {renderedPlugins}
                </div>
                <div className="plugin-gallery-info">
                    <div>
                        {this.state.info ? this.state.info : ''}
                    </div>
                </div>
            </div>
        )
    }
}


PluginViewComponent.propTypes = {
    plugins: PropTypes.array.isRequired,
}

/**
 * A container which will connect to the database and set the 'plugins' prop to contain a list of all plugins
 * that exist in the database
 */
export default createContainer(() => {
    Meteor.subscribe('plugins');

    return {
        plugins: Plugins.find({}).fetch(),
    };
}, PluginViewComponent);