import React, { Component } from 'react';
import { Meteor } from 'meteor/meteor';
import PropTypes from 'prop-types';
import Dialog from 'material-ui/Dialog';
import TextField from 'material-ui/TextField';
import RaisedButton from 'material-ui/RaisedButton';
import FileUploadComponent from '../../mapeditor/FileUploadComponent';

class AddMapDialog extends Component {
  constructor(props) {
    super(props);

    this.state = {
      imageID: '',
    };
  }

  handleSubmit = () => {
    Meteor.call(
      'maps.addNewMap',
      this.mapName.getValue(),
      parseInt(this.mapWidth.getValue()),
      parseInt(this.mapHeight.getValue()),
      parseFloat(this.mapScale.getValue()),
      this.state.imageID,
    );

    this.props.onClose();
  }

  uploadComplete = (fileObj) => {
    this.setState({ imageID: fileObj._id });
  }

  render() {
    return (
      <Dialog
        title="Add New Map"
        modal={false}
        open={this.props.isOpen}
        onRequestClose={this.props.onClose}
        style={{ width: '40%', left: '30%', textAlign: 'center' }}
      >
        <TextField ref={(name) => { this.mapName = name; }} floatingLabelText="Map Name" />
        <TextField ref={(height) => { this.mapHeight = height; }} floatingLabelText="Map Image Height (px)" />
        <TextField ref={(width) => { this.mapWidth = width; }} floatingLabelText="Map Image Width (px)" />
        <TextField ref={(scale) => { this.mapScale = scale; }} floatingLabelText="Map Scale" />
        <FileUploadComponent onUploadComplete={this.uploadComplete} />
        <RaisedButton onClick={this.handleSubmit} style={{ marginTop: '10px' }}>Submit</RaisedButton>
      </Dialog>
    );
  }
}

AddMapDialog.propTypes = {
  onClose: PropTypes.func.isRequired,
  isOpen: PropTypes.bool.isRequired,
};

export default AddMapDialog;
