import React, { Component } from 'react';
import { Meteor } from 'meteor/meteor';
import PropTypes from 'prop-types';
import Dialog from 'material-ui/Dialog';
import TextField from 'material-ui/TextField';
import RaisedButton from 'material-ui/RaisedButton';
import AutoComplete from 'material-ui/AutoComplete';

class EditMapDialog extends Component {
  constructor(props) {
    super(props);

    this.state = {
      dataSource: [],
      mapName: '',
      mapWidth: '',
      mapHeight: '',
      mapScale: '',
    };
  }

  componentDidMount() {
    Meteor.call('maps.getMapNames', function(err, res) {
      this.setState({ dataSource: res });
    }.bind(this));
  }

  selectMap = (mapName) => {
    Meteor.call('maps.getMap', mapName, function(err, res) {
      if (res) {
        this.setState({
          mapName: res.name,
          mapHeight: res.image.height,
          mapWidth: res.image.width,
          mapScale: res.scale,
        });
      }
    }.bind(this));
  }

  handleSubmit = () => {
    Meteor.call('maps.getMap', this.state.mapName, function(err, res) {
      if (res) {
        Meteor.call(
          'maps.updateMap',
          res._id,
          this.mapName.getValue(),
          this.mapWidth.getValue(),
          this.mapHeight.getValue(),
          this.mapScale.getValue(),
        );
      }
    }.bind(this));

    this.props.onClose();
  }

  render() {
    return (
      <Dialog
        title="Edit Map"
        modal={false}
        open={this.props.isOpen}
        onRequestClose={this.props.onClose}
        style={{ width: '40%', left: '30%', textAlign: 'center' }}
      >
        <AutoComplete ref={(origName) => { this.origName = origName; }} onUpdateInput={this.selectMap} dataSource={this.state.dataSource} floatingLabelText="Map Name" />
        <TextField ref={(name) => { this.mapName = name; }} floatingLabelText="New Map Name" value={this.state.mapName} />
        <TextField ref={(height) => { this.mapHeight = height; }} floatingLabelText="Map Image Height (px)" value={this.state.mapHeight} />
        <TextField ref={(width) => { this.mapWidth = width; }} floatingLabelText="Map Image Width (px)" value={this.state.mapWidth} />
        <TextField ref={(scale) => { this.mapScale = scale; }} floatingLabelText="Map Scale" value={this.state.mapScale} />
        <RaisedButton onClick={this.handleSubmit} style={{ marginTop: '10px' }}>Submit</RaisedButton>
      </Dialog>
    );
  }
}

EditMapDialog.propTypes = {
  onClose: PropTypes.func.isRequired,
  isOpen: PropTypes.bool.isRequired,
};

export default EditMapDialog;
