import React, {Component, PropTypes} from 'react';
import {Meteor} from 'meteor/meteor';
import {Nav, NavText} from "react-sidenav";

import UserMapComponent from "./UserMapComponent";
import SideBar from "../sidenav/SideBar";
import {toTitleCase} from "../../api/algorithms/strings";

var closePopup = false;

export default class UserLayoutComponent extends Component {

    /**
     *
     * @param props
     */
    constructor(props){
        super(props);

        this.state = {
            selectedItem: 'default',
            mapName: null,
            listMapNames: [],
        }
    }

    componentWillMount(){
        Meteor.call('maps.getMapNames', function(err, names){
            if(!err){
                this.setState({listMapNames: names});
            }
        }.bind(this));
    }

    /**
     * Sets this components state to determine which component to render in the future
     * Also triggers any popups over the current map overlay, this way we only are rendering one instance of the
     * map editor as opposed to calling them inside render which creates a new map-editor instance for each selection
     * @param id Sidebar ID to differentiate the options
     * @param parent Parent component of this option (for nested options)
     * TODO: Fill this in with the individual plugin screens instead
     */
    selectItem = (id, parent) => {
        let names = this.state.listMapNames;

        if(!!names) {
            names.map((name) => {
                switch(id){
                    case 'map-editor/' + name:
                        this.setState({mapName: name});
                        break;
                }
            })
        }
    }

    /**
     * Renders whichever item is currently selected based on this components state.
     */
    renderSelectedItem(){
        switch(this.state.selectedItem){
            // Selected the map editor, load this component
            case 'default':
                return(<UserMapComponent mapName={this.state.mapName} loadMap={this.setMapName}/>);
                break;

            default:
                console.log('Unknown selection \"' + this.state.selectedItem + '\" selected.');
        }
    }

    setMapName = (mapID) => {
        Meteor.call('maps.getMapByID', mapID, function(err, res){
            if(!err){
                this.setState({mapName: res.name});
            }
        }.bind(this))
    }



    render(){
        let toRender = this.renderSelectedItem();

        return(
            <div className="main-layout">
                {/* Side Bar 
                <div className="main-component sidebar-container" style={{background: '#0191C8', color: '#FFF', width: 200, height: '100%'}}>
                    <SideBar plugins={this.props.plugins} mapNames={this.state.listMapNames} handleSwitch={this.selectItem}/>
                </div>*/}

                {/* Viewing Container */}
                <div className="main-component">
                    {toRender}
                </div>
            </div>

        )
    }
}